@@ -18,7 +18,7 @@ def load_flight(
 ):
     """
     Download, clean, and filter flight data from 2017.
-    The original dataset can be found `here <https://www.transtats.bts.gov/DL_SelectFields.asp?DB_Short_Name=On-Time&Table_ID=236>`_.
+    The original dataset can be found `here <https://www.transtats.bts.gov/ot_delay/ot_delaycause1.asp>`_.
 
     Args:
 
