@@ -1,5 +1,6 @@
 import numpy as np
 import pandas as pd
+import pandas.api.types as pdtypes
 from woodwork.column_schema import ColumnSchema
 from woodwork.logical_types import Boolean, BooleanNullable, Datetime, Ordinal
 
@@ -35,7 +36,19 @@ class GreaterThan(TransformPrimitive):
     description_template = "whether {} is greater than {}"
 
     def get_function(self):
-        return np.greater
+        def greater_than(val1, val2):
+            val1_is_categorical = pdtypes.is_categorical_dtype(val1)
+            val2_is_categorical = pdtypes.is_categorical_dtype(val2)
+            if val1_is_categorical and val2_is_categorical:
+                if not all(val1.cat.categories == val2.cat.categories):
+                    return np.nan
+            elif val1_is_categorical or val2_is_categorical:
+                # This can happen because CFM does not set proper dtypes for intermediate
+                # features, so some agg features that should be Ordinal don't yet have correct type.
+                return np.nan
+            return val1 > val2
+
+        return greater_than
 
     def generate_name(self, base_feature_names):
         return "%s > %s" % (base_feature_names[0], base_feature_names[1])
@@ -70,6 +83,11 @@ class GreaterThanScalar(TransformPrimitive):
 
     def get_function(self):
         def greater_than_scalar(vals):
+            if (
+                pdtypes.is_categorical_dtype(vals)
+                and self.value not in vals.cat.categories
+            ):
+                return np.nan
             return vals > self.value
 
         return greater_than_scalar
@@ -106,7 +124,19 @@ class GreaterThanEqualTo(TransformPrimitive):
     description_template = "whether {} is greater than or equal to {}"
 
     def get_function(self):
-        return np.greater_equal
+        def greater_than_equal(val1, val2):
+            val1_is_categorical = pdtypes.is_categorical_dtype(val1)
+            val2_is_categorical = pdtypes.is_categorical_dtype(val2)
+            if val1_is_categorical and val2_is_categorical:
+                if not all(val1.cat.categories == val2.cat.categories):
+                    return np.nan
+            elif val1_is_categorical or val2_is_categorical:
+                # This can happen because CFM does not set proper dtypes for intermediate
+                # features, so some agg features that should be Ordinal don't yet have correct type.
+                return np.nan
+            return val1 >= val2
+
+        return greater_than_equal
 
     def generate_name(self, base_feature_names):
         return "%s >= %s" % (base_feature_names[0], base_feature_names[1])
@@ -143,6 +173,11 @@ class GreaterThanEqualToScalar(TransformPrimitive):
 
     def get_function(self):
         def greater_than_equal_to_scalar(vals):
+            if (
+                pdtypes.is_categorical_dtype(vals)
+                and self.value not in vals.cat.categories
+            ):
+                return np.nan
             return vals >= self.value
 
         return greater_than_equal_to_scalar
@@ -179,7 +214,19 @@ class LessThan(TransformPrimitive):
     description_template = "whether {} is less than {}"
 
     def get_function(self):
-        return np.less
+        def less_than(val1, val2):
+            val1_is_categorical = pdtypes.is_categorical_dtype(val1)
+            val2_is_categorical = pdtypes.is_categorical_dtype(val2)
+            if val1_is_categorical and val2_is_categorical:
+                if not all(val1.cat.categories == val2.cat.categories):
+                    return np.nan
+            elif val1_is_categorical or val2_is_categorical:
+                # This can happen because CFM does not set proper dtypes for intermediate
+                # features, so some agg features that should be Ordinal don't yet have correct type.
+                return np.nan
+            return val1 < val2
+
+        return less_than
 
     def generate_name(self, base_feature_names):
         return "%s < %s" % (base_feature_names[0], base_feature_names[1])
@@ -214,6 +261,11 @@ class LessThanScalar(TransformPrimitive):
 
     def get_function(self):
         def less_than_scalar(vals):
+            if (
+                pdtypes.is_categorical_dtype(vals)
+                and self.value not in vals.cat.categories
+            ):
+                return np.nan
             return vals < self.value
 
         return less_than_scalar
@@ -250,7 +302,19 @@ class LessThanEqualTo(TransformPrimitive):
     description_template = "whether {} is less than or equal to {}"
 
     def get_function(self):
-        return np.less_equal
+        def less_than_equal(val1, val2):
+            val1_is_categorical = pdtypes.is_categorical_dtype(val1)
+            val2_is_categorical = pdtypes.is_categorical_dtype(val2)
+            if val1_is_categorical and val2_is_categorical:
+                if not all(val1.cat.categories == val2.cat.categories):
+                    return np.nan
+            elif val1_is_categorical or val2_is_categorical:
+                # This can happen because CFM does not set proper dtypes for intermediate
+                # features, so some agg features that should be Ordinal don't yet have correct type.
+                return np.nan
+            return val1 <= val2
+
+        return less_than_equal
 
     def generate_name(self, base_feature_names):
         return "%s <= %s" % (base_feature_names[0], base_feature_names[1])
@@ -287,6 +351,11 @@ class LessThanEqualToScalar(TransformPrimitive):
 
     def get_function(self):
         def less_than_equal_to_scalar(vals):
+            if (
+                pdtypes.is_categorical_dtype(vals)
+                and self.value not in vals.cat.categories
+            ):
+                return np.nan
             return vals <= self.value
 
         return less_than_equal_to_scalar
@@ -627,20 +696,8 @@ class MultiplyNumeric(TransformPrimitive):
 
     name = "multiply_numeric"
     input_types = [
-        [
-            ColumnSchema(semantic_tags={"numeric"}),
-            ColumnSchema(semantic_tags={"numeric"}),
-        ],
-        [ColumnSchema(semantic_tags={"numeric"}), ColumnSchema(logical_type=Boolean)],
-        [ColumnSchema(logical_type=Boolean), ColumnSchema(semantic_tags={"numeric"})],
-        [
-            ColumnSchema(semantic_tags={"numeric"}),
-            ColumnSchema(logical_type=BooleanNullable),
-        ],
-        [
-            ColumnSchema(logical_type=BooleanNullable),
-            ColumnSchema(semantic_tags={"numeric"}),
-        ],
+        ColumnSchema(semantic_tags={"numeric"}),
+        ColumnSchema(semantic_tags={"numeric"}),
     ]
     return_type = ColumnSchema(semantic_tags={"numeric"})
     commutative = True
@@ -728,6 +785,70 @@ class MultiplyBoolean(TransformPrimitive):
         return "%s * %s" % (base_feature_names[0], base_feature_names[1])
 
 
+class MultiplyNumericBoolean(TransformPrimitive):
+    """Element-wise multiplication of a numeric list with a boolean list.
+
+    Description:
+        Given a list of numeric values X and a list of
+        boolean values Y, return the values in X where
+        the corresponding value in Y is True.
+
+    Examples:
+        >>> multiply_numeric_boolean = MultiplyNumericBoolean()
+        >>> multiply_numeric_boolean([2, 1, 2], [True, True, False]).tolist()
+        [2, 1, 0]
+        >>> multiply_numeric_boolean([2, None, None], [True, True, False]).tolist()
+        [2.0, nan, nan]
+        >>> multiply_numeric_boolean([2, 1, 2], [True, True, None]).tolist()
+        [2.0, 1.0, nan]
+    """
+
+    name = "multiply_numeric_boolean"
+    input_types = [
+        [
+            ColumnSchema(semantic_tags={"numeric"}),
+            ColumnSchema(logical_type=Boolean),
+        ],
+        [
+            ColumnSchema(semantic_tags={"numeric"}),
+            ColumnSchema(logical_type=BooleanNullable),
+        ],
+        [
+            ColumnSchema(logical_type=Boolean),
+            ColumnSchema(semantic_tags={"numeric"}),
+        ],
+        [
+            ColumnSchema(logical_type=BooleanNullable),
+            ColumnSchema(semantic_tags={"numeric"}),
+        ],
+    ]
+    return_type = ColumnSchema(semantic_tags={"numeric"})
+    compatibility = [Library.PANDAS, Library.DASK]
+    commutative = True
+    description_template = "the product of {} and {}"
+
+    def get_function(self):
+        def multiply_numeric_boolean(ser1, ser2):
+            if pdtypes.is_bool_dtype(ser1):
+                mask = ser1
+                vals = ser2
+            else:
+                mask = ser2
+                vals = ser1
+            vals_not_null = vals.notnull()
+            # Only apply mask where the input is not null
+            mask = mask.where(vals_not_null)
+            result = vals.where(mask, mask.replace({False: 0}))
+            # Replace all pd.NA with np.nan to avoid WW init error
+            result = result.replace({pd.NA: np.nan})
+            return result
+
+        return multiply_numeric_boolean
+
+    def generate_name(self, base_feature_names):
+        return "%s * %s" % (base_feature_names[0], base_feature_names[1])
+
+
 class DivideNumeric(TransformPrimitive):
     """Element-wise division of two lists.
 
