@@ -8,7 +8,7 @@ from woodwork.logical_types import (
     Categorical,
     Double,
     EmailAddress,
-    NaturalLanguage
+    NaturalLanguage,
 )
 
 from featuretools.primitives.base import TransformPrimitive
@@ -24,6 +24,7 @@ class IsNull(TransformPrimitive):
         >>> is_null([1, None, 3]).tolist()
         [False, True, False]
     """
+
     name = "is_null"
     input_types = [ColumnSchema()]
     return_type = ColumnSchema(logical_type=Boolean)
@@ -33,6 +34,7 @@ class IsNull(TransformPrimitive):
     def get_function(self):
         def isnull(array):
             return array.isnull()
+
         return isnull
 
 
@@ -44,9 +46,10 @@ class Absolute(TransformPrimitive):
         >>> absolute([3.0, -5.0, -2.4]).tolist()
         [3.0, 5.0, 2.4]
     """
+
     name = "absolute"
-    input_types = [ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    input_types = [ColumnSchema(semantic_tags={"numeric"})]
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the absolute value of {}"
 
@@ -62,9 +65,10 @@ class SquareRoot(TransformPrimitive):
         >>> sqrt([9.0, 16.0, 4.0]).tolist()
         [3.0, 4.0, 2.0]
     """
+
     name = "square_root"
-    input_types = [ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    input_types = [ColumnSchema(semantic_tags={"numeric"})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={"numeric"})
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the square root of {}"
 
@@ -80,9 +84,10 @@ class NaturalLogarithm(TransformPrimitive):
         >>> log([1.0, np.e]).tolist()
         [0.0, 1.0]
     """
+
     name = "natural_logarithm"
-    input_types = [ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    input_types = [ColumnSchema(semantic_tags={"numeric"})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={"numeric"})
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the natural logarithm of {}"
 
@@ -98,9 +103,10 @@ class Sine(TransformPrimitive):
         >>> sin([-np.pi/2.0, 0.0, np.pi/2.0]).tolist()
         [-1.0, 0.0, 1.0]
     """
+
     name = "sine"
-    input_types = [ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    input_types = [ColumnSchema(semantic_tags={"numeric"})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={"numeric"})
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the sine of {}"
 
@@ -116,9 +122,10 @@ class Cosine(TransformPrimitive):
         >>> cos([0.0, np.pi/2.0, np.pi]).tolist()
         [1.0, 6.123233995736766e-17, -1.0]
     """
+
     name = "cosine"
-    input_types = [ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    input_types = [ColumnSchema(semantic_tags={"numeric"})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={"numeric"})
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the cosine of {}"
 
@@ -134,9 +141,10 @@ class Tangent(TransformPrimitive):
         >>> tan([-np.pi, 0.0, np.pi/2.0]).tolist()
         [1.2246467991473532e-16, 0.0, 1.633123935319537e+16]
     """
+
     name = "tangent"
-    input_types = [ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(logical_type=Double, semantic_tags={'numeric'})
+    input_types = [ColumnSchema(semantic_tags={"numeric"})]
+    return_type = ColumnSchema(logical_type=Double, semantic_tags={"numeric"})
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the tangent of {}"
 
@@ -154,15 +162,17 @@ class NumCharacters(TransformPrimitive):
         ...                 'final1']).tolist()
         [16, 11, 6]
     """
-    name = 'num_characters'
+
+    name = "num_characters"
     input_types = [ColumnSchema(logical_type=NaturalLanguage)]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the number of characters in {}"
 
     def get_function(self):
         def character_counter(array):
-            return array.fillna('').str.len()
+            return array.fillna("").str.len()
+
         return character_counter
 
 
@@ -177,15 +187,17 @@ class NumWords(TransformPrimitive):
         ...            'Also works with sentences. Second sentence!']).tolist()
         [4, 2, 1, 6]
     """
-    name = 'num_words'
+
+    name = "num_words"
     input_types = [ColumnSchema(logical_type=NaturalLanguage)]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the number of words in {}"
 
     def get_function(self):
         def word_counter(array):
-            return array.fillna('').str.count(' ') + 1
+            return array.fillna("").str.count(" ") + 1
+
         return word_counter
 
 
@@ -198,6 +210,7 @@ class IsIn(TransformPrimitive):
         >>> is_in(['string', 10.5, False]).tolist()
         [True, False, True]
     """
+
     name = "isin"
     input_types = [ColumnSchema()]
     return_type = ColumnSchema(logical_type=Boolean)
@@ -206,19 +219,21 @@ class IsIn(TransformPrimitive):
     def __init__(self, list_of_outputs=None):
         self.list_of_outputs = list_of_outputs
         if not list_of_outputs:
-            stringified_output_list = '[]'
+            stringified_output_list = "[]"
         else:
-            stringified_output_list = ', '.join([str(x) for x in list_of_outputs])
-        self.description_template = "whether {{}} is in {}".format(stringified_output_list)
+            stringified_output_list = ", ".join([str(x) for x in list_of_outputs])
+        self.description_template = "whether {{}} is in {}".format(
+            stringified_output_list
+        )
 
     def get_function(self):
         def pd_is_in(array):
             return array.isin(self.list_of_outputs or [])
+
         return pd_is_in
 
     def generate_name(self, base_feature_names):
-        return u"%s.isin(%s)" % (base_feature_names[0],
-                                 str(self.list_of_outputs))
+        return "%s.isin(%s)" % (base_feature_names[0], str(self.list_of_outputs))
 
 
 class Diff(TransformPrimitive):
@@ -237,15 +252,17 @@ class Diff(TransformPrimitive):
         >>> diff(values).tolist()
         [nan, 9.0, -7.0, 1.0, 11.0]
     """
+
     name = "diff"
-    input_types = [ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    input_types = [ColumnSchema(semantic_tags={"numeric"})]
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     uses_full_dataframe = True
     description_template = "the difference from the previous value of {}"
 
     def get_function(self):
         def pd_diff(values):
             return values.diff()
+
         return pd_diff
 
 
@@ -257,15 +274,17 @@ class Negate(TransformPrimitive):
         >>> negate([1.0, 23.2, -7.0]).tolist()
         [-1.0, -23.2, 7.0]
     """
+
     name = "negate"
-    input_types = [ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    input_types = [ColumnSchema(semantic_tags={"numeric"})]
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the negation of {}"
 
     def get_function(self):
         def negate(vals):
             return vals * -1
+
         return negate
 
     def generate_name(self, base_feature_names):
@@ -280,14 +299,18 @@ class Not(TransformPrimitive):
         >>> not_func([True, True, False]).tolist()
         [False, False, True]
     """
+
     name = "not"
-    input_types = [[ColumnSchema(logical_type=Boolean)], [ColumnSchema(logical_type=BooleanNullable)]]
+    input_types = [
+        [ColumnSchema(logical_type=Boolean)],
+        [ColumnSchema(logical_type=BooleanNullable)],
+    ]
     return_type = ColumnSchema(logical_type=BooleanNullable)
     compatibility = [Library.PANDAS, Library.DASK, Library.SPARK]
     description_template = "the negation of {}"
 
     def generate_name(self, base_feature_names):
-        return u"NOT({})".format(base_feature_names[0])
+        return "NOT({})".format(base_feature_names[0])
 
     def get_function(self):
         return np.logical_not
@@ -306,10 +329,11 @@ class Percentile(TransformPrimitive):
         >>> percentile([10, 15, 1, None, 20]).tolist()
         [0.5, 0.75, 0.25, nan, 1.0]
     """
-    name = 'percentile'
+
+    name = "percentile"
     uses_full_dataframe = True
-    input_types = [ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    input_types = [ColumnSchema(semantic_tags={"numeric"})]
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     description_template = "the percentile rank of {}"
 
     def get_function(self):
@@ -331,14 +355,16 @@ class URLToDomain(TransformPrimitive):
         >>> url_to_domain(urls).tolist()
         ['play.google.com', 'google.co.in', 'facebook.com']
     """
+
     name = "url_to_domain"
     input_types = [ColumnSchema(logical_type=URL)]
-    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={'category'})
+    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={"category"})
 
     def get_function(self):
         def url_to_domain(x):
-            p = r'^(?:https?:\/\/)?(?:[^@\/\n]+@)?(?:www\.)?([^:\/?\n]+)'
+            p = r"^(?:https?:\/\/)?(?:[^@\/\n]+@)?(?:www\.)?([^:\/?\n]+)"
             return x.str.extract(p, expand=False)
+
         return url_to_domain
 
 
@@ -358,14 +384,16 @@ class URLToProtocol(TransformPrimitive):
         >>> url_to_protocol(urls).to_list()
         ['https', 'http', nan]
     """
+
     name = "url_to_protocol"
     input_types = [ColumnSchema(logical_type=URL)]
-    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={'category'})
+    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={"category"})
 
     def get_function(self):
         def url_to_protocol(x):
-            p = r'^(https|http)(?:\:)'
+            p = r"^(https|http)(?:\:)"
             return x.str.extract(p, expand=False)
+
         return url_to_protocol
 
 
@@ -386,15 +414,16 @@ class URLToTLD(TransformPrimitive):
         >>> url_to_tld(urls).to_list()
         ['com', 'in', 'com']
     """
+
     name = "url_to_tld"
     input_types = [ColumnSchema(logical_type=URL)]
-    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={'category'})
+    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={"category"})
 
     def get_function(self):
-        self.tlds_pattern = r'(?:\.({}))'.format('|'.join(COMMON_TLDS))
+        self.tlds_pattern = r"(?:\.({}))".format("|".join(COMMON_TLDS))
 
         def url_to_domain(x):
-            p = r'^(?:https?:\/\/)?(?:[^@\/\n]+@)?(?:www\.)?([^:\/?\n]+)'
+            p = r"^(?:https?:\/\/)?(?:[^@\/\n]+@)?(?:www\.)?([^:\/?\n]+)"
             return x.str.extract(p, expand=False)
 
         def url_to_tld(x):
@@ -402,6 +431,7 @@ class URLToTLD(TransformPrimitive):
             df = domains.str.extractall(self.tlds_pattern)
             matches = df.groupby(level=0).last()[0]
             return matches.reindex(x.index)
+
         return url_to_tld
 
 
@@ -419,6 +449,7 @@ class IsFreeEmailDomain(TransformPrimitive):
         >>> is_free_email_domain(['name@gmail.com', 'name@featuretools.com']).tolist()
         [True, False]
     """
+
     name = "is_free_email_domain"
     input_types = [ColumnSchema(logical_type=EmailAddress)]
     return_type = ColumnSchema(logical_type=BooleanNullable)
@@ -428,31 +459,34 @@ class IsFreeEmailDomain(TransformPrimitive):
     def get_function(self):
         file_path = self.get_filepath(self.filename)
 
-        free_domains = pd.read_csv(file_path, header=None, names=['domain'])
-        free_domains['domain'] = free_domains.domain.str.strip()
+        free_domains = pd.read_csv(file_path, header=None, names=["domain"])
+        free_domains["domain"] = free_domains.domain.str.strip()
 
         def is_free_email_domain(emails):
             # if the input is empty return an empty Series
             if len(emails) == 0:
                 return pd.Series([])
 
-            emails_df = pd.DataFrame({'email': emails})
+            emails_df = pd.DataFrame({"email": emails})
 
             # if all emails are NaN expand won't propogate NaNs and will fail on indexing
-            if emails_df['email'].isnull().all():
-                emails_df['domain'] = np.nan
+            if emails_df["email"].isnull().all():
+                emails_df["domain"] = np.nan
             else:
                 # .str.strip() and .str.split() return NaN for NaN values and propogate NaNs into new columns
-                emails_df['domain'] = emails_df['email'].str.strip().str.split('@', expand=True)[1]
+                emails_df["domain"] = (
+                    emails_df["email"].str.strip().str.split("@", expand=True)[1]
+                )
 
-            emails_df['is_free'] = emails_df['domain'].isin(free_domains['domain'])
+            emails_df["is_free"] = emails_df["domain"].isin(free_domains["domain"])
 
             # if there are any NaN domain values, change the series type to allow for
             # both bools and NaN values and set is_free to NaN for the NaN domains
-            if emails_df['domain'].isnull().values.any():
-                emails_df['is_free'] = emails_df['is_free'].astype(np.object)
-                emails_df.loc[emails_df['domain'].isnull(), 'is_free'] = np.nan
+            if emails_df["domain"].isnull().values.any():
+                emails_df["is_free"] = emails_df["is_free"].astype(np.object)
+                emails_df.loc[emails_df["domain"].isnull(), "is_free"] = np.nan
             return emails_df.is_free.values
+
         return is_free_email_domain
 
 
@@ -469,9 +503,10 @@ class EmailAddressToDomain(TransformPrimitive):
         >>> email_address_to_domain(['name@gmail.com', 'name@featuretools.com']).tolist()
         ['gmail.com', 'featuretools.com']
     """
+
     name = "email_address_to_domain"
     input_types = [ColumnSchema(logical_type=EmailAddress)]
-    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={'category'})
+    return_type = ColumnSchema(logical_type=Categorical, semantic_tags={"category"})
 
     def get_function(self):
         def email_address_to_domain(emails):
@@ -479,16 +514,19 @@ class EmailAddressToDomain(TransformPrimitive):
             if len(emails) == 0:
                 return pd.Series([])
 
-            emails_df = pd.DataFrame({'email': emails})
+            emails_df = pd.DataFrame({"email": emails})
 
             # if all emails are NaN expand won't propogate NaNs and will fail on indexing
-            if emails_df['email'].isnull().all():
-                emails_df['domain'] = np.nan
-                emails_df['domain'] = emails_df['domain'].astype(object)
+            if emails_df["email"].isnull().all():
+                emails_df["domain"] = np.nan
+                emails_df["domain"] = emails_df["domain"].astype(object)
             else:
                 # .str.strip() and .str.split() return NaN for NaN values and propogate NaNs into new columns
-                emails_df['domain'] = emails_df['email'].str.strip().str.split('@', expand=True)[1]
+                emails_df["domain"] = (
+                    emails_df["email"].str.strip().str.split("@", expand=True)[1]
+                )
             return emails_df.domain.values
+
         return email_address_to_domain
 
 
@@ -519,9 +557,13 @@ class NumericLag(TransformPrimitive):
         >>> lag_fill_value(pd.Series(pd.date_range(start="2020-01-01", periods=4, freq='D')), [1, 2, 3, 4]).tolist()
         [100, 1, 2, 3]
     """
+
     name = "numeric_lag"
-    input_types = [ColumnSchema(semantic_tags={'time_index'}), ColumnSchema(semantic_tags={'numeric'})]
-    return_type = ColumnSchema(semantic_tags={'numeric'})
+    input_types = [
+        ColumnSchema(semantic_tags={"time_index"}),
+        ColumnSchema(semantic_tags={"numeric"}),
+    ]
+    return_type = ColumnSchema(semantic_tags={"numeric"})
     uses_full_dataframe = True
 
     def __init__(self, periods=1, fill_value=None):
@@ -532,4 +574,5 @@ class NumericLag(TransformPrimitive):
         def lag(time_index, numeric):
             x = pd.Series(numeric.values, index=time_index.values)
             return x.shift(periods=self.periods, fill_value=self.fill_value).values
+
         return lag
