@@ -6,25 +6,25 @@ from featuretools.__main__ import cli
 
 
 def test_info():
-    subprocess.check_output(['featuretools', 'info'])
+    subprocess.check_output(["featuretools", "info"])
 
 
 def test_list_primitives():
-    subprocess.check_output(['featuretools', 'list-primitives'])
+    subprocess.check_output(["featuretools", "list-primitives"])
 
 
 def test_cli_help():
-    subprocess.check_output(['featuretools'])
+    subprocess.check_output(["featuretools"])
 
 
 def test_cli_info():
     with pytest.raises(SystemExit):
-        cli(['info'])
+        cli(["info"])
 
 
 def test_cli_list_primitives():
     with pytest.raises(SystemExit):
-        cli(['list-primitives'])
+        cli(["list-primitives"])
 
 
 def test_cli():
