@@ -9,10 +9,10 @@ def test_nmostcommon_categorical():
     n_most = NMostCommon(3)
     expected = pd.Series([1.0, 2.0, np.nan])
 
-    ints = pd.Series([1, 2, 1, 1]).astype('int64')
+    ints = pd.Series([1, 2, 1, 1]).astype("int64")
     assert pd.Series(n_most(ints)).equals(expected)
 
-    cats = pd.Series([1, 2, 1, 1]).astype('category')
+    cats = pd.Series([1, 2, 1, 1]).astype("category")
     assert pd.Series(n_most(cats)).equals(expected)
 
     # Value counts includes data for categories that are not present in data.
