@@ -5,7 +5,7 @@ import numpy as np
 import pandas as pd
 import pytest
 from woodwork.column_schema import ColumnSchema
-from woodwork.logical_types import Boolean, Datetime, Integer
+from woodwork.logical_types import Boolean, Datetime, Integer, Ordinal
 
 import featuretools as ft
 from featuretools.computational_backends.feature_set import FeatureSet
@@ -25,6 +25,9 @@ from featuretools.primitives import (
     DivideNumericScalar,
     Equal,
     EqualScalar,
+    First,
+    GreaterThan,
+    GreaterThanEqualTo,
     GreaterThanEqualToScalar,
     GreaterThanScalar,
     Haversine,
@@ -32,11 +35,15 @@ from featuretools.primitives import (
     IsIn,
     IsNull,
     Latitude,
+    LessThan,
+    LessThanEqualTo,
     LessThanEqualToScalar,
     LessThanScalar,
     Longitude,
     Mode,
+    MultiplyBoolean,
     MultiplyNumeric,
+    MultiplyNumericBoolean,
     MultiplyNumericScalar,
     Not,
     NotEqual,
@@ -1456,3 +1463,164 @@ def test_cfm_with_lag_and_non_nullable_column(pd_es):
         .isnull()
         .all()
     )
+
+
+def test_comparisons_with_ordinal_valid_inputs(es):
+    if es.dataframe_type == Library.SPARK.value:
+        pytest.xfail(
+            "Categorical dtypes not used in Spark, and comparison works as expected without error."
+        )
+    new_df = es["log"]
+    new_df.ww["ordinal_valid"] = new_df["priority_level"]
+
+    es.replace_dataframe("log", new_df)
+    es["log"].ww.set_types(
+        logical_types={
+            "ordinal_valid": Ordinal(order=[0, 1, 2]),
+        }
+    )
+    valid_features = [
+        ft.Feature(es["log"].ww["priority_level"]) > 1,
+        ft.Feature(es["log"].ww["priority_level"]) >= 1,
+        ft.Feature(es["log"].ww["priority_level"]) < 1,
+        ft.Feature(es["log"].ww["priority_level"]) <= 1,
+        ft.Feature(es["log"].ww["priority_level"])
+        > ft.Feature(es["log"].ww["ordinal_valid"]),
+        ft.Feature(es["log"].ww["priority_level"])
+        >= ft.Feature(es["log"].ww["ordinal_valid"]),
+        ft.Feature(es["log"].ww["priority_level"])
+        < ft.Feature(es["log"].ww["ordinal_valid"]),
+        ft.Feature(es["log"].ww["priority_level"])
+        <= ft.Feature(es["log"].ww["ordinal_valid"]),
+    ]
+    fm = ft.calculate_feature_matrix(
+        entityset=es,
+        features=valid_features,
+    )
+    feature_cols = [f.get_name() for f in valid_features]
+    fm = to_pandas(fm)
+    for col in feature_cols:
+        assert fm[col].notnull().any()
+
+
+def test_comparisons_with_ordinal_invalid_inputs(es):
+    if es.dataframe_type == Library.SPARK.value:
+        pytest.xfail(
+            "Categorical dtypes not used in Spark, and comparison works as expected without error."
+        )
+    new_df = es["log"]
+    new_df.ww["ordinal_invalid"] = new_df["priority_level"].astype(int) + 10
+
+    es.replace_dataframe("log", new_df)
+    es["log"].ww.set_types(
+        logical_types={
+            "ordinal_invalid": Ordinal(order=[10, 11, 12]),
+        }
+    )
+
+    invalid_features = [
+        ft.Feature(es["log"].ww["priority_level"]) > 10,
+        ft.Feature(es["log"].ww["priority_level"]) >= 10,
+        ft.Feature(es["log"].ww["priority_level"]) < 10,
+        ft.Feature(es["log"].ww["priority_level"]) <= 10,
+        ft.Feature(es["log"].ww["priority_level"])
+        > ft.Feature(es["log"].ww["ordinal_invalid"]),
+        ft.Feature(es["log"].ww["priority_level"])
+        >= ft.Feature(es["log"].ww["ordinal_invalid"]),
+        ft.Feature(es["log"].ww["priority_level"])
+        < ft.Feature(es["log"].ww["ordinal_invalid"]),
+        ft.Feature(es["log"].ww["priority_level"])
+        <= ft.Feature(es["log"].ww["ordinal_invalid"]),
+    ]
+    fm = ft.calculate_feature_matrix(
+        entityset=es,
+        features=invalid_features,
+    )
+
+    feature_cols = [f.get_name() for f in invalid_features]
+    fm = to_pandas(fm)
+    for col in feature_cols:
+        assert fm[col].isnull().all()
+
+
+def test_comparisons_with_ordinal_valid_inputs_that_dont_work_but_should(pd_es):
+    # TODO: Remvoe this test once the correct behavior is implemented in CFM
+    # The following test covers a scenario where an intermediate feature doesn't have the correct type
+    # because Woodwork has not yet been initialized. This calculation should work and return valid True/False
+    # values. This should be fixed in a future PR, but until a fix is implemented null values are returned to
+    # prevent calculate_feature_matrix from raising an Error when calculating features generated by DFS.
+
+    priority_level = ft.Feature(pd_es["log"].ww["priority_level"])
+    first_priority = ft.AggregationFeature(
+        priority_level, parent_dataframe_name="customers", primitive=First
+    )
+    engagement = ft.Feature(pd_es["customers"].ww["engagement_level"])
+    invalid_but_should_be_valid = [
+        ft.TransformFeature([engagement, first_priority], primitive=LessThan),
+        ft.TransformFeature([engagement, first_priority], primitive=LessThanEqualTo),
+        ft.TransformFeature([engagement, first_priority], primitive=GreaterThan),
+        ft.TransformFeature([engagement, first_priority], primitive=GreaterThanEqualTo),
+    ]
+    fm = ft.calculate_feature_matrix(
+        entityset=pd_es,
+        features=invalid_but_should_be_valid,
+    )
+
+    feature_cols = [f.get_name() for f in invalid_but_should_be_valid]
+    fm = to_pandas(fm)
+    for col in feature_cols:
+        assert fm[col].isnull().all()
+
+
+def test_multiply_numeric_boolean():
+    test_cases = [
+        {"val": 100, "mask": True, "expected": 100},
+        {"val": 100, "mask": False, "expected": 0},
+        {"val": 0, "mask": False, "expected": 0},
+        {"val": 100, "mask": pd.NA, "expected": pd.NA},
+        {"val": pd.NA, "mask": pd.NA, "expected": pd.NA},
+        {"val": pd.NA, "mask": True, "expected": pd.NA},
+        {"val": pd.NA, "mask": False, "expected": pd.NA},
+    ]
+
+    multiply_numeric_boolean = MultiplyNumericBoolean()
+    for input in test_cases:
+        vals = pd.Series(input["val"])
+        mask = pd.Series(input["mask"])
+        actual = multiply_numeric_boolean(vals, mask).tolist()[0]
+        expected = input["expected"]
+        if pd.isnull(expected):
+            assert pd.isnull(actual)
+        else:
+            assert actual == input["expected"]
+
+
+def test_feature_multiplication(es):
+    numeric_ft = ft.Feature(es["customers"].ww["age"])
+    boolean_ft = ft.Feature(es["customers"].ww["loves_ice_cream"])
+
+    mult_numeric = numeric_ft * numeric_ft
+    mult_boolean = boolean_ft * boolean_ft
+    mult_numeric_boolean = numeric_ft * boolean_ft
+    mult_numeric_boolean2 = boolean_ft * numeric_ft
+
+    assert issubclass(type(mult_numeric.primitive), MultiplyNumeric)
+    assert issubclass(type(mult_boolean.primitive), MultiplyBoolean)
+    assert issubclass(type(mult_numeric_boolean.primitive), MultiplyNumericBoolean)
+    assert issubclass(type(mult_numeric_boolean2.primitive), MultiplyNumericBoolean)
+
+    # Test with nullable types
+    es["customers"].ww.set_types(
+        logical_types={"age": "IntegerNullable", "loves_ice_cream": "BooleanNullable"}
+    )
+    numeric_ft = ft.Feature(es["customers"].ww["age"])
+    boolean_ft = ft.Feature(es["customers"].ww["loves_ice_cream"])
+    mult_numeric = numeric_ft * numeric_ft
+    mult_boolean = boolean_ft * boolean_ft
+    mult_numeric_boolean = numeric_ft * boolean_ft
+    mult_numeric_boolean2 = boolean_ft * numeric_ft
+
+    assert issubclass(type(mult_numeric.primitive), MultiplyNumeric)
+    assert issubclass(type(mult_boolean.primitive), MultiplyBoolean)
+    assert issubclass(type(mult_numeric_boolean.primitive), MultiplyNumericBoolean)
+    assert issubclass(type(mult_numeric_boolean2.primitive), MultiplyNumericBoolean)
